Class: Belvo::TaxRetentionsOptions
- Inherits:
-
Object
- Object
- Belvo::TaxRetentionsOptions
- Defined in:
- lib/belvo/options.rb
Overview
Contains configurable properties of a tax retention
data in Belvo. By default, this is set to true and we return a
201 Created response. When set to false, the data won't be persisted
and we return a 200 OK response.
tax retention in the response.
Instance Attribute Summary collapse
-
#attach_xml ⇒ Object
When set to
true, you will receive the XML. -
#save_data ⇒ Object
Indicates whether or not to persist the.
Instance Attribute Details
#attach_xml ⇒ Object
When set to true, you will receive the XML
174 175 176 177 178 179 180 |
# File 'lib/belvo/options.rb', line 174 class TaxRetentionsOptions < Faraday::Options.new( :save_data, :attach_xml, :date_from, :date_to ) end |
#save_data ⇒ Object
Indicates whether or not to persist the
174 175 176 177 178 179 180 |
# File 'lib/belvo/options.rb', line 174 class TaxRetentionsOptions < Faraday::Options.new( :save_data, :attach_xml, :date_from, :date_to ) end |